@@ -1,5 +1,5 @@
 package Module::Signature;
-$Module::Signature::VERSION = '0.68';
+$Module::Signature::VERSION = '0.69';
 
 use 5.005;
 use strict;
@@ -143,7 +143,8 @@ sub _verify {
 }
 
 sub _has_gpg {
-    `gpg --version` =~ /GnuPG.*?(\S+)\s*$/m or return;
+    my $gpg = _which_gpg();
+    `$gpg --version` =~ /GnuPG.*?(\S+)\s*$/m or return;
     return $1;
 }
 
@@ -213,6 +214,20 @@ sub _default_skip {
              or /~$/ or /\.old$/ or /\#$/ or /^\.#/;
 }
 
+my $which_gpg;
+sub _which_gpg {
+    # Cache it so we don't need to keep checking.
+    return $which_gpg if $which_gpg;
+
+    for my $gpg_bin ('gpg', 'gpg2', 'gnupg', 'gnupg2') {
+        my $version = `$gpg_bin --version 2>&1`;
+        if( $version && $version =~ /GnuPG/ ) {
+            $which_gpg = $gpg_bin;
+            return $which_gpg;
+        }
+    }
+}
+
 sub _verify_gpg {
     my ($sigtext, $plaintext, $version) = @_;
 
@@ -221,9 +236,10 @@ sub _verify_gpg {
 
     my $keyserver = _keyserver($version);
 
+    my $gpg = _which_gpg();
     my @quiet = $Verbose ? () : qw(-q --logger-fd=1);
     my @cmd = (
-        qw(gpg --verify --batch --no-tty), @quiet, ($KeyServer ? (
+        $gpg, qw(--verify --batch --no-tty), @quiet, ($KeyServer ? (
             "--keyserver=$keyserver",
             ($AutoKeyRetrieve and $version ge '1.0.7')
                 ? '--keyserver-options=auto-key-retrieve'
@@ -380,8 +396,10 @@ sub _sign_gpg {
     die "Could not write to $sigfile"
         if -e $sigfile and (-d $sigfile or not -w $sigfile);
 
+    my $gpg = _which_gpg();
+
     local *D;
-    open D, "| gpg --clearsign >> $sigfile.tmp" or die "Could not call gpg: $!";
+    open D, "| $gpg --clearsign >> $sigfile.tmp" or die "Could not call $gpg: $!";
     print D $plaintext;
     close D;
 
@@ -410,7 +428,7 @@ sub _sign_gpg {
     # This doesn't work because the output from verify goes to STDERR.
     # If I try to redirect it using "--logger-fd 1" it just hangs.
     # WTF?
-    my @verify = `gpg --batch --verify $SIGNATURE`;
+    my @verify = `$gpg --batch --verify $SIGNATURE`;
     while (@verify) {
         if (/key ID ([0-9A-F]+)$/) {
             $key_id = $1;
@@ -423,7 +441,7 @@ sub _sign_gpg {
     my $found_key;
     if (defined $key_id && defined $key_name) {
         my $keyserver = _keyserver($version);
-        while (`gpg --batch --keyserver=$keyserver --search-keys '$key_name'`) {
+        while (`$gpg --batch --keyserver=$keyserver --search-keys '$key_name'`) {
             if (/^\(\d+\)/) {
                 $found_name = 0;
             } elsif ($found_name) {
